@@ -1010,8 +1010,13 @@ def direct_import_ext(module_name, blocked_modules=None):
     from mercurial import demandimport
     if blocked_modules:
         for blocked_module in blocked_modules:
-            if blocked_module not in demandimport.ignore:
-                demandimport.ignore.append(blocked_module)
+            if hasattr(demandimport, 'IGNORES'):
+                # Mercurial 4.7 introduced set demandimport.IGNORES
+                demandimport.IGNORES.add(blocked_module)
+            else:
+                # Earlier it was demandimport.ignore, a list
+                if blocked_module not in demandimport.ignore:
+                    demandimport.ignore.append(blocked_module)
 
     # Various attempts to define is_demandimport_enabled
     try:
